==> naiveproxy-95.0.4638.54-3.tar.gz: naiveproxy-95.0.4638.54-3/src/net/test/embedded_test_server/http_connection.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef NET_TEST_EMBEDDED_TEST_SERVER_HTTP_CONNECTION_H_
#define NET_TEST_EMBEDDED_TEST_SERVER_HTTP_CONNECTION_H_

#include <memory>
#include "base/callback_forward.h"
#include "base/memory/weak_ptr.h"
#include "net/base/completion_once_callback.h"
#include "net/test/embedded_test_server/embedded_test_server_connection_listener.h"
#include "net/test/embedded_test_server/http_request.h"
#include "net/test/embedded_test_server/http_response.h"

namespace net {

class StreamSocket;

namespace test_server {

// Wraps the connection socket. Accepts incoming data and sends responses.
// If a valid request is parsed, then |callback_| is invoked.
class HttpConnection {
 public:
  HttpConnection() = default;
  virtual ~HttpConnection() = default;
  HttpConnection(HttpConnection&) = delete;
  virtual HttpConnection& operator=(HttpConnection&) = delete;

  // Sends the |response_string| to the client and calls |callback| once done.
  virtual void SendResponseBytes(const std::string& response_string,
                                 SendCompleteCallback callback) = 0;

  // Notify that the socket is ready to receive data (which may not be
  // immediately, due to SSL handshake). May call the delegate's HandleRequest()
  // or CloseConnection() methods, and may call them asynchronously.
  virtual void OnSocketReady() = 0;

  // Pass ownership of the socket. This will likely invalidate the connection.
  virtual std::unique_ptr<StreamSocket> TakeSocket() = 0;

  virtual const StreamSocket& Socket() = 0;
  virtual base::WeakPtr<HttpConnection> GetWeakPtr() = 0;
};

}  // namespace test_server
}  // namespace net

#endif  // NET_TEST_EMBEDDED_TEST_SERVER_HTTP_CONNECTION_H_

==> naiveproxy-106.0.5249.91-2.tar.gz: naiveproxy-106.0.5249.91-2/src/net/test/embedded_test_server/http_connection.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef NET_TEST_EMBEDDED_TEST_SERVER_HTTP_CONNECTION_H_
#define NET_TEST_EMBEDDED_TEST_SERVER_HTTP_CONNECTION_H_

#include <memory>

#include "base/callback_forward.h"
#include "base/memory/weak_ptr.h"
#include "net/base/completion_once_callback.h"
#include "net/test/embedded_test_server/embedded_test_server_connection_listener.h"
#include "net/test/embedded_test_server/http_request.h"
#include "net/test/embedded_test_server/http_response.h"

namespace net {

class StreamSocket;

namespace test_server {

class EmbeddedTestServer;

// Wraps the connection socket. Accepts incoming data and sends responses.
// If a valid request is parsed, then |callback_| is invoked.
class HttpConnection {
 public:
  enum class Protocol { kHttp1, kHttp2 };

  HttpConnection() = default;
  virtual ~HttpConnection() = default;
  HttpConnection(HttpConnection&) = delete;
  virtual HttpConnection& operator=(HttpConnection&) = delete;

  // Construct the correct connection based on the server's protocol.
  static std::unique_ptr<HttpConnection> Create(
      std::unique_ptr<StreamSocket> socket,
      EmbeddedTestServerConnectionListener* listener,
      EmbeddedTestServer* server,
      Protocol protocol);

  // Notify that the socket is ready to receive data (which may not be
  // immediately, due to SSL handshake). May call the delegate's HandleRequest()
  // or CloseConnection() methods, and may call them asynchronously.
  virtual void OnSocketReady() = 0;

  // Pass ownership of the socket. This will likely invalidate the connection.
  virtual std::unique_ptr<StreamSocket> TakeSocket() = 0;

  virtual StreamSocket* Socket() = 0;
  virtual base::WeakPtr<HttpConnection> GetWeakPtr() = 0;
};

}  // namespace test_server
}  // namespace net

#endif  // NET_TEST_EMBEDDED_TEST_SERVER_HTTP_CONNECTION_H_
